/*
    AutoX11, a tool to automate tasks in an X11 environment
    Copyright (C) 2014  Alicia <alicia@ion.nu>

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, version 3 of the License.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <stdlib.h>
#include <X11/Xlib.h>
#include <X11/cursorfont.h>
#include "grab.h"

// int main()
int grabrect(Display* display, struct rect* rect)
{
//  Display* display=XOpenDisplay(getenv("DISPLAY"));
  Cursor cursor=XCreateFontCursor(display, XC_crosshair);
  int status=XGrabPointer(display, RootWindow(display, 0), 0, ButtonPressMask|ButtonReleaseMask, GrabModeSync, GrabModeAsync, None, cursor, CurrentTime);
  if(status!=GrabSuccess){return -1;}
  int x1=-1, y1=-1, x2=-1, y2=-1;
  XEvent event;
  while(x1<0||y1<0||x2<0||y2<0)
  {
  XAllowEvents(display, SyncPointer, CurrentTime);
  XWindowEvent(display, RootWindow(display, 0), ButtonPressMask|ButtonReleaseMask, &event);
  switch (event.type) {
  case ButtonPress:
//    printf("Got buttonpress at %i x %i\n", event.xbutton.x_root, event.xbutton.y_root);
    x1=event.xbutton.x_root;
    y1=event.xbutton.y_root;
    break;
  case ButtonRelease:
    if(x1<0||y1<0){break;} // Need to press first (otherwise be getting a release event from something else
//    printf("Got buttonrelease at %i x %i\n", event.xbutton.x_root, event.xbutton.y_root);
    x2=event.xbutton.x_root;
    y2=event.xbutton.y_root;
    break;
  }
  }
  XUngrabPointer(display, CurrentTime);
//  printf("Grabbed from %ix%i to %ix%i, a %ix%i area\n", x1, y1, x2, y2, abs(x2-x1), abs(y2-y1));
  int tmp;
  if(x1>x2){tmp=x1; x1=x2; x2=tmp;}
  if(y1>y2){tmp=y1; y1=y2; y2=tmp;}
  rect->x=x1;
  rect->y=y1;
  rect->w=x2-x1;
  rect->h=y2-y1;
  return 0;
}
